==> gtkpod_0.72-2.orig.tar.gz: gtkpod-0.72-2/src/confirmation.h <==
/*
|  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
|  Part of the gtkpod project.
| 
|  URL: http://gtkpod.sourceforge.net/
| 
|  This program is free software; you can redistribute it and/or modify
|  it under the terms of the GNU General Public License as published by
|  the Free Software Foundation; either version 2 of the License, or
|  (at your option) any later version.
| 
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
| 
|  You should have received a copy of the GNU General Public License
|  along with this program; if not, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
| 
|  iTunes and iPod are trademarks of Apple
| 
|  This product is not supported/written/published by Apple!
|
|  $Id: confirmation.h,v 1.9 2003/09/23 19:57:14 samc Exp $
*/

#ifndef __CONFIRMATION_H__
#define __CONFIRMATION_H__


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

typedef void (*ConfHandler)(gpointer user_data1, gpointer user_data2);
typedef void (*ConfHandlerOpt)(gboolean state);

/* states for gtkpod_confirmation options */
typedef enum {
    CONF_STATE_TRUE,
    CONF_STATE_FALSE,
    CONF_STATE_INVERT_TRUE,
    CONF_STATE_INVERT_FALSE,
} CONF_STATE;

gboolean gtkpod_confirmation (gint id,
			      gboolean modal,
			      gchar *title,
			      gchar *label,
			      gchar *text,
			      gchar *option1_text,
			      CONF_STATE option1_state,
			      ConfHandlerOpt option1_handler,
			      gchar *option2_text,
			      CONF_STATE option2_state,
			      ConfHandlerOpt option2_handler,
			      gboolean never_again,
			      ConfHandlerOpt confirm_again_handler,
			      ConfHandler ok_handler,
			      ConfHandler apply_handler,
			      ConfHandler cancel_handler,
			      gpointer user_data1,
			      gpointer user_data2);

/* predefined IDs for use with gtkpod_confirmation() */
enum {
    CONF_ID_IPOD_DIR = 0,
    CONF_ID_GTKPOD_WARNING
} CONF_ID;

/* pass this as handler if you don't want the corresponding button to
   be drawn */
#define CONF_NO_BUTTON ((ConfHandler)-1)

#endif

==> gtkpod_0.88.1.orig.tar.gz: gtkpod-0.88.1/src/confirmation.h <==
/*
|  Copyright (C) 2002-2003 Jorg Schuler <jcsjcs at users.sourceforge.net>
|  Part of the gtkpod project.
|
|  URL: http://gtkpod.sourceforge.net/
|
|  This program is free software; you can redistribute it and/or modify
|  it under the terms of the GNU General Public License as published by
|  the Free Software Foundation; either version 2 of the License, or
|  (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
|
|  You should have received a copy of the GNU General Public License
|  along with this program; if not, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
|
|  iTunes and iPod are trademarks of Apple
|
|  This product is not supported/written/published by Apple!
|
|  $Id: confirmation.h,v 1.12 2004/03/30 15:39:18 jcsjcs Exp $
*/

#ifndef __CONFIRMATION_H__
#define __CONFIRMATION_H__


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

typedef void (*ConfHandler)(gpointer user_data1, gpointer user_data2);
typedef void (*ConfHandlerOpt)(gboolean state);

/* states for gtkpod_confirmation options */
typedef enum {
    CONF_STATE_TRUE,
    CONF_STATE_FALSE,
    CONF_STATE_INVERT_TRUE,
    CONF_STATE_INVERT_FALSE,
} CONF_STATE;

GtkResponseType gtkpod_confirmation (gint id,
				     gboolean modal,
				     gchar *title,
				     gchar *label,
				     gchar *text,
				     gchar *option1_text,
				     CONF_STATE option1_state,
				     ConfHandlerOpt option1_handler,
				     gchar *option2_text,
				     CONF_STATE option2_state,
				     ConfHandlerOpt option2_handler,
				     gboolean never_again,
				     ConfHandlerOpt confirm_again_handler,
				     ConfHandler ok_handler,
				     ConfHandler apply_handler,
				     ConfHandler cancel_handler,
				     gpointer user_data1,
				     gpointer user_data2);

/* predefined IDs for use with gtkpod_confirmation() */
enum {
    CONF_ID_IPOD_DIR = 0,
    CONF_ID_GTKPOD_WARNING,
    CONF_ID_DANGLING0,
    CONF_ID_DANGLING1
} CONF_ID;

void CONF_NULL_HANDLER (gpointer d1, gpointer d2);

#endif
